pub fn write_step(
ir: &CadIr,
w: &mut impl Write,
opts: &StepWriteOptions,
) -> Result<StepReport, StepError>Expand description
Serialize ir as an AP214 STEP file into w, returning a report of what was
written and what was lost.
pub fn write_step(
ir: &CadIr,
w: &mut impl Write,
opts: &StepWriteOptions,
) -> Result<StepReport, StepError>Serialize ir as an AP214 STEP file into w, returning a report of what was
written and what was lost.